@@ -5,20 +5,20 @@ import pytest
 from fastapi import FastAPI
 from httpx import AsyncClient
 from starlette import status
-from fakeredis.aioredis import FakeRedis
+from redis.asyncio import ConnectionPool, Redis
 
 
 @pytest.mark.anyio
 async def test_setting_value(
     fastapi_app: FastAPI,
-    fake_redis: FakeRedis,
+    fake_redis_pool: ConnectionPool,
     client: AsyncClient,
 ) -> None:
     """
     Tests that you can set value in redis.
 
     :param fastapi_app: current application fixture.
-    :param fake_redis: fake redis instance.
+    :param fake_redis_pool: fake redis pool.
     :param client: client fixture.
     """
     {%- if cookiecutter.api_type == 'rest' %}
@@ -53,26 +53,28 @@ async def test_setting_value(
     {%- endif %}
 
     assert response.status_code == status.HTTP_200_OK
-    actual_value = await fake_redis.get(test_key)
-    assert actual_value == test_val
+    async with Redis(connection_pool=fake_redis_pool) as redis:
+        actual_value = await redis.get(test_key)
+    assert actual_value.decode() == test_val
 
 
 @pytest.mark.anyio
 async def test_getting_value(
     fastapi_app: FastAPI,
-    fake_redis: FakeRedis,
+    fake_redis_pool: ConnectionPool,
     client: AsyncClient,
 ) -> None:
     """
     Tests that you can get value from redis by key.
 
     :param fastapi_app: current application fixture.
-    :param fake_redis: fake redis instance.
+    :param fake_redis_pool: fake redis pool.
     :param client: client fixture.
     """
     test_key = uuid.uuid4().hex
     test_val = uuid.uuid4().hex
-    await fake_redis.set(test_key, test_val)
+    async with Redis(connection_pool=fake_redis_pool) as redis:
+        await redis.set(test_key, test_val)
 
     {%- if cookiecutter.api_type == 'rest' %}
     url = fastapi_app.url_path_for('get_redis_value')
